#ifndef SIMPLE_LOGGER_HPP
#define SIMPLE_LOGGER_HPP

enum level{unknown, trace, debug, info, warning, error, fatal};

//Uncomment and change this define if you want to use a different file for the logs
//#define logfilename "logger.log"
#ifdef LOGGER_ENABLED
	#include <logger.hpp>
#else
	#include <iostream>
	#include <fstream>
#endif //LOGGER_ENABLED

//Allow to specifiy the name of a thread so log will display this name
#ifdef LOGGER_ENABLED
	#define THREAD_NAME(name) logger::setThreadName((name))
#else
	#define THREAD_NAME(name) //logger::setThreadName((name))
#endif //LOGGER_ENABLED

//Log a message of the specified severity level
//level can be : unknown, trace, debug, info, warning, error, fatal

#ifdef LOGGER_ENABLED
	#define LOG(level) BOOST_LOG_SEV(logger::get(), (level))
	
//	#define LOG(level) BOOST_LOG_STREAM_WITH_PARAMS((logger::get()), (::boost::log::keywords::severity = (level)))
	
//	BOOST_LOG_STREAM_WITH_PARAMS_INTERNAL((logger::get()), BOOST_PP_CAT(_boost_log_record_, __COUNTER__), (::boost::log::keywords::severity = (level)))
#else
	static std::ofstream dev_null("/dev/null");
	template <level Level> inline std::ostream& logger(){
		return dev_null;
	}
	
	template <> inline std::ostream& logger<error>(){
		return std::cerr<<std::endl<<"ERROR: ";
	}
	
	template <> inline std::ostream& logger<fatal>(){
		return std::cerr<<std::endl<<"FATAL: ";
	}
	#define LOG(level) logger<level>()
#endif //LOGGER_ENABLED


//Log a message (severity set to unknown)
#ifdef LOGGER_ENABLED
	#define LOGGER BOOST_LOG_SEV(logger::get(), unknown)
#else
	#define LOGGER dev_null
#endif //LOGGER_ENABLED

#endif //SIMPLE_LOGGER_HPP


/* Here is a simple example of how to use the logger

#include <simple_logger.hpp>

#include <iostream>

int main(int, char*[])
{
	THREAD_NAME("Main");
	
	LOG(trace) << "Trace level message";
	LOG(debug) << "Debug level message";
	LOG(info) << "Info level message";
	LOG(warning) << "Warning level message";
	LOG(error) << "Error level message";
	LOG(fatal) << "Fatal level message";
	
	LOGGER<<"Some message";

	return 0;
}
*/
